contexttools.StaffChangeMark
============================

.. abjad-lineage:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark

.. autoclass:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.target_context
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.staff
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark.__repr__
   :noindex:
